@@ -454,7 +454,11 @@ public final class Module {
      * @throws ModuleLoadException if the named module failed to load
      */
     public static <S> ServiceLoader<S> loadServiceFromCallerModuleLoader(String name, Class<S> serviceType) throws ModuleLoadException {
-        return getCallerModuleLoader().loadModule(name).loadService(serviceType);
+        ModuleLoader ml = getCallerModuleLoader();
+        if (ml != null) {
+            return ml.loadModule(name).loadService(serviceType);
+        }
+        throw new ModuleLoadException(name);
     }
 
     /**
@@ -594,7 +598,11 @@ public final class Module {
      * @return the module loader, or {@code null} if none is set
      */
     public static ModuleLoader getContextModuleLoader() {
-        return Module.forClassLoader(Thread.currentThread().getContextClassLoader(), true).getModuleLoader();
+        Module module = Module.forClassLoader(Thread.currentThread().getContextClassLoader(), true);
+        if (module != null) {
+            return module.getModuleLoader();
+        }
+        return null;
     }
 
     /**
@@ -622,7 +630,11 @@ public final class Module {
      * @throws ModuleLoadException if the module could not be loaded
      */
     public static Module getModuleFromCallerModuleLoader(final String name) throws ModuleLoadException {
-        return getCallerModuleLoader().loadModule(name);
+        ModuleLoader ml = getCallerModuleLoader();
+        if (ml != null) {
+            return ml.loadModule(name);
+        }
+        throw new ModuleLoadException(name);
     }
 
     /**
@@ -778,16 +790,13 @@ public final class Module {
         }
         log.trace("Attempting to find resource %s in %s", canonPath, this);
         final String path = pathOf(canonPath);
-        final URLConnectionResource jaxpResource = ModuleClassLoader.jaxpImplResources.get(canonPath);
         final Map<String, List<LocalLoader>> paths = getPathsUnchecked();
         final List<LocalLoader> loaders = paths.get(path);
         if (loaders != null) {
             for (LocalLoader loader : loaders) {
                 final Iterator<Resource> iterator = loader.loadResourceLocal(canonPath).iterator();
                 if (iterator.hasNext()) {
-                    final URL url = iterator.next().getURL();
-                    if (jaxpResource != null) log.jaxpResourceLoaded(url, this);
-                    return url;
+                    return iterator.next().getURL();
                 }
             }
         }
@@ -795,16 +804,9 @@ public final class Module {
         if (fallbackLoader != null) {
             final Iterator<Resource> iterator = fallbackLoader.loadResourceLocal(canonPath).iterator();
             if (iterator.hasNext()) {
-                final URL url = iterator.next().getURL();
-                if (jaxpResource != null) log.jaxpResourceLoaded(url, this);
-                return url;
+                return iterator.next().getURL();
             }
         }
-        if (jaxpResource != null) {
-            final URL url = jaxpResource.getURL();
-            log.jaxpResourceLoaded(url, this);
-            return url;
-        }
         return null;
     }
 
@@ -823,7 +825,6 @@ public final class Module {
         }
         log.trace("Attempting to find resource %s in %s", canonPath, this);
         final String path = pathOf(canonPath);
-        final URLConnectionResource jaxpResource = ModuleClassLoader.jaxpImplResources.get(canonPath);
         final Map<String, List<LocalLoader>> paths = getPathsUnchecked();
         final List<LocalLoader> loaders = paths.get(path);
         if (loaders != null) {
@@ -831,9 +832,7 @@ public final class Module {
                 final List<Resource> resourceList = loader.loadResourceLocal(canonPath);
                 final Iterator<Resource> iterator = resourceList.iterator();
                 if (iterator.hasNext()) {
-                    final Resource resource = iterator.next();
-                    if (jaxpResource != null) log.jaxpResourceLoaded(resource.getURL(), this);
-                    return resource.openStream();
+                    return iterator.next().openStream();
                 }
             }
         }
@@ -842,15 +841,9 @@ public final class Module {
             final List<Resource> resourceList = fallbackLoader.loadResourceLocal(canonPath);
             final Iterator<Resource> iterator = resourceList.iterator();
             if (iterator.hasNext()) {
-                final Resource resource = iterator.next();
-                if (jaxpResource != null) log.jaxpResourceLoaded(resource.getURL(), this);
-                return resource.openStream();
+                return iterator.next().openStream();
             }
         }
-        if (jaxpResource != null) {
-            log.jaxpResourceLoaded(jaxpResource.getURL(), this);
-            return jaxpResource.openStream();
-        }
         return null;
     }
 
@@ -873,7 +866,6 @@ public final class Module {
         }
         log.trace("Attempting to find all resources %s in %s", canonPath, this);
         final String path = pathOf(canonPath);
-        final URLConnectionResource jaxpResource = ModuleClassLoader.jaxpImplResources.get(canonPath);
         final Map<String, List<LocalLoader>> paths = getPathsUnchecked();
         final List<LocalLoader> loaders = paths.get(path);
 
@@ -882,9 +874,7 @@ public final class Module {
             for (LocalLoader loader : loaders) {
                 final List<Resource> resourceList = loader.loadResourceLocal(canonPath);
                 for (Resource resource : resourceList) {
-                    final URL url = resource.getURL();
-                    if (jaxpResource != null) log.jaxpResourceLoaded(url, this);
-                    list.add(url);
+                    list.add(resource.getURL());
                 }
             }
         }
@@ -892,16 +882,9 @@ public final class Module {
         if (fallbackLoader != null) {
             final List<Resource> resourceList = fallbackLoader.loadResourceLocal(canonPath);
             for (Resource resource : resourceList) {
-                final URL url = resource.getURL();
-                if (jaxpResource != null) log.jaxpResourceLoaded(url, this);
-                list.add(url);
+                list.add(resource.getURL());
             }
         }
-        if (jaxpResource != null) {
-            final URL url = jaxpResource.getURL();
-            log.jaxpResourceLoaded(url, this);
-            list.add(url);
-        }
 
         return list.size() == 0 ? ConcurrentClassLoader.EMPTY_ENUMERATION : Collections.enumeration(list);
     }
