@@ -18,7 +18,6 @@
 
 package org.jboss.modules.log;
 
-import java.net.URL;
 import org.jboss.modules.Module;
 import org.jboss.modules.ModuleLoader;
 
@@ -91,16 +90,4 @@ public final class NoopModuleLogger implements ModuleLogger {
     @Override
     public void classDefined(final String name, final Module module) {
     }
-
-    @Override
-    public void providerUnloadable(String name, ClassLoader loader) {
-    }
-
-    @Override
-    public void jaxpClassLoaded(final Class<?> jaxpClass, final Module module) {
-    }
-
-    @Override
-    public void jaxpResourceLoaded(final URL resourceURL, final Module module) {
-    }
 }
