@@ -18,9 +18,8 @@
 
 package org.jboss.modules.util;
 
+import org.jboss.modules.DelegatingModuleLoader;
 import org.jboss.modules.Module;
-import org.jboss.modules.ModuleLoadException;
-import org.jboss.modules.ModuleLoader;
 import org.jboss.modules.ModuleSpec;
 
 import java.util.HashMap;
@@ -32,19 +31,17 @@ import java.util.Map;
  *
  * @author John E. Bailey
  */
-public class TestModuleLoader extends ModuleLoader {
+public class TestModuleLoader extends DelegatingModuleLoader {
 
     private final Map<String, ModuleSpec> moduleSpecs = new HashMap<>();
 
-    protected Module preloadModule(final String name) throws ModuleLoadException {
-        return super.preloadModule(name);
+    public TestModuleLoader() {
+        super(Module.getSystemModuleLoader(), NO_FINDERS);
     }
 
     @Override
-    protected ModuleSpec findModule(String name) throws ModuleLoadException {
-        final ModuleSpec moduleSpec = moduleSpecs.get(name);
-        if(moduleSpec == null) throw new ModuleLoadException("No module spec found for module " + name);
-        return moduleSpec;
+    protected ModuleSpec findModule(String name) {
+        return moduleSpecs.get(name);
     }
 
     public void addModuleSpec(final ModuleSpec moduleSpec) {
